@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.16 2003/07/13 14:53:51 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.18 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -401,6 +401,18 @@ bbs_thread_info_free(BBSThreadGUIInfo *info)
       info->offsets = NULL;
     }
 
+  if (info->last_name != NULL)
+    {
+      G_FREE(info->last_name);
+      info->last_name = NULL;
+    }
+
+  if (info->last_mail != NULL)
+    {
+      G_FREE(info->last_mail);
+      info->last_mail = NULL;
+    }
+
   G_FREE(info);
 }
 
@@ -987,6 +999,14 @@ render_response(OchushaBBSThread *thread, gint number,
       gchar *mailto = convert_string(context->handler.converter,
 				     context->handler.helper,
 				     response->mailto, -1);
+#if 0
+      if (mailto == NULL)
+	{
+	  fprintf(stderr, "XXX: name=%s\n", name);
+	  fprintf(stderr, "XXX: response->name=%s\n", response->name);
+	  fprintf(stderr, "XXX: response->mailto=%s\n", response->mailto);
+	}
+#endif
       bbs_thread_view_append_text_as_link(view, name, -1, mailto);
       G_FREE(mailto);
       G_FREE(name);
