@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.5 2003/06/03 12:14:21 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.6 2003/06/12 02:02:08 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -77,8 +77,6 @@ struct _BBSThreadView
   /* Хåե˻Ȥ */
   GtkTextIter iter;
   GSList *tags;
-  int alt_link_tag;
-
 
   /* ʥطǻȤ */
   gint last_offset;
@@ -97,6 +95,9 @@ struct _BBSThreadView
 #if ENABLE_REGEXP
   regex_t regexp;
 #endif
+  guint alt_link_tag		: 1;
+  guint alt_sage_tag		: 1;
+
   guint regexp_available	: 1;
   guint search_direction	: 1;
   guint enable_wrap		: 1;
@@ -159,6 +160,9 @@ void bbs_thread_view_append_text(BBSThreadView *view, const gchar *text,
 void bbs_thread_view_append_text_as_link(BBSThreadView *view,
 					 const gchar *text, int len,
 					 const gchar *link);
+void bbs_thread_view_append_text_as_sage(BBSThreadView *view,
+					 const gchar *text, int len,
+					 const gchar *link);
 void bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget);
 
 GtkTextTag *bbs_thread_view_get_tag_by_name(BBSThreadView *view,
