@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.17 2003/06/20 18:14:40 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.18 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -1022,6 +1022,10 @@ boardlist_read_board_element_cb(OchushaBBSTable *table,
   info->filter.ignore_threshold
     = ochusha_utils_get_attribute_int(board_attributes,
 				      "filter.ignore_threshold");
+  info->last_name = ochusha_utils_get_attribute_string(board_attributes,
+						       "last_name");
+  info->last_mail = ochusha_utils_get_attribute_string(board_attributes,
+						       "last_mail");
   return;
 }
 
@@ -1060,7 +1064,8 @@ boardlist_write_category_element_cb(OchushaBBSTable *table,
 	  "        </attribute>\n", (board)->attribute)
 
 #define OUTPUT_BOARD_ATTRIBUTE_STRING(file, board, attribute)		\
-  fprintf(file,								\
+  if ((board)->attribute != NULL)					\
+    fprintf(file,							\
 	  "        <attribute name=\"" #attribute	"\">\n"		\
 	  "          <string>%s</string>\n"				\
 	  "        </attribute>\n", (board)->attribute)
@@ -1074,6 +1079,8 @@ boardlist_write_board_element_cb(OchushaBBSTable *table,
 {
   BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board, application);
   OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, enable_filter);
+  OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, info, last_name);
+  OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, info, last_mail);
 
   if (info->filter.rule != NULL)
     {
