@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.25 2003/06/21 16:23:53 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.32 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -43,6 +43,7 @@
 #include "threadlist_filter.h"
 #include "threadlist_view.h"
 #include "paned_notebook.h"
+#include "response_editor.h"
 #include "ugly_gtk2utils.h"
 
 #include "worker.h"
@@ -109,6 +110,8 @@ static void go_to_bottom_button_cb(GtkWidget *widget,
 				   OchushaApplication *application);
 static void go_to_top_button_cb(GtkWidget *widget,
 				OchushaApplication *application);
+static GtkWidget *create_write_dialog(OchushaApplication *application,
+				      OchushaBBSThread *thread);
 
 
 static pthread_mutex_t thread_list_lock;
@@ -214,6 +217,10 @@ threadlist_read_thread_element_cb(OchushaBulletinBoard *board,
   info->view_rank = ochusha_utils_get_attribute_int(hash_table, "view_rank");
   info->view_ignored = ochusha_utils_get_attribute_int(hash_table,
 						       "view_ignored");
+  info->last_name = ochusha_utils_get_attribute_string(hash_table,
+						       "last_name");
+  info->last_mail = ochusha_utils_get_attribute_string(hash_table,
+						       "last_mail");
   if ((info->view_flags & BBS_THREAD_HIDDEN) != 0)
     thread->number_of_responses_read = 0;
 
@@ -228,7 +235,8 @@ threadlist_read_thread_element_cb(OchushaBulletinBoard *board,
 	  "      </attribute>\n", (thread)->attribute)
 
 #define OUTPUT_THREAD_ATTRIBUTE_STRING(file, thread, attribute)		\
-  fprintf(file,								\
+  if ((thread)->attribute != NULL)					\
+    fprintf(file,							\
 	  "      <attribute name=\"" #attribute	"\">\n"			\
 	  "        <string>%s</string>\n"				\
 	  "      </attribute>\n", (thread)->attribute)
@@ -249,6 +257,8 @@ threadlist_write_thread_element_cb(OchushaBulletinBoard *board,
 				  view_flags);
       OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, info, view_rank);
       OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, info, view_ignored);
+      OUTPUT_THREAD_ATTRIBUTE_STRING(threadlist_xml, info, last_name);
+      OUTPUT_THREAD_ATTRIBUTE_STRING(threadlist_xml, info, last_mail);
     }
 
   if ((info->view_flags & BBS_THREAD_HIDDEN) != 0)
@@ -271,6 +281,18 @@ bulletin_board_gui_info_free(BulletinBoardGUIInfo *info)
   if (info->properties_dialog != NULL)
     gtk_widget_destroy(info->properties_dialog);
 
+  if (info->last_name != NULL)
+    {
+      G_FREE(info->last_name);
+      info->last_name = NULL;
+    }
+
+  if (info->last_mail != NULL)
+    {
+      G_FREE(info->last_mail);
+      info->last_mail = NULL;
+    }
+
   G_FREE(info);
 }
 
@@ -1486,25 +1508,138 @@ finalize_bulletin_board_view(OchushaBulletinBoard *board, GtkWidget *widget)
 }
 
 
+static const gchar *
+reverse_strpbrk(const gchar *string, const gchar *charset)
+{
+  const gchar *s = string;
+  while (*s != '\0')
+    {
+      if (strchr(charset, *s) == NULL)
+	return s;
+      s++;
+    }
+
+  return NULL;
+}
+
+
 void
 write_response(OchushaApplication *application)
 {
   GtkWidget *view;
   OchushaBBSThread *thread;
   IconLabel *tab_label;
+  GtkWidget *write_dialog;
+  int response_id;
+  gboolean result;
 
   get_current_thread(application, &view, &thread, &tab_label);
   if (view == NULL || thread == NULL)
     return;
 
-  {
-    /*
-     * TODO: ǽ񤭹ߤޤ礦
-     */
+  write_dialog = create_write_dialog(application, thread);
+
+  response_id = gtk_dialog_run(GTK_DIALOG(write_dialog));
+
+  if (response_id == GTK_RESPONSE_OK)
+    {
+      ResponseEditor *editor = g_object_get_data(G_OBJECT(write_dialog),
+						 "editor");
+      gchar *message;
+      OchushaBBSResponse response;
+
+      response.name = response_editor_get_name(editor);
+      response.mailto = response_editor_get_mail(editor);
+      message = response_editor_get_response(editor);
+      response.content = message;
+
+      if (message != NULL && *message != '\0')
+	{
+	  result = ochusha_bbs_thread_post_response(thread,
+						    &application->config,
+						    &response);
+	  g_free(message);
+	  if (result)
+	    {
+	      BBSThreadGUIInfo *thread_info = ensure_bbs_thread_info(thread);
+	      BulletinBoardGUIInfo *board_info
+		= ensure_bulletin_board_info(thread->board, application);
+	      gboolean number_only = reverse_strpbrk(response.name,
+						     "0123456789") == NULL;
+
+	      if (thread_info->last_name == NULL
+		  || strcmp(thread_info->last_name, response.name) != 0)
+		{
+		  if (thread_info->last_name != NULL)
+		    G_FREE(thread_info->last_name);
+		  thread_info->last_name = G_STRDUP(response.name);
+		}
+
+	      if (thread_info->last_mail == NULL
+		  || strcmp(thread_info->last_mail, response.mailto) != 0)
+		{
+		  if (thread_info->last_mail != NULL)
+		    G_FREE(thread_info->last_mail);
+		  thread_info->last_mail = G_STRDUP(response.mailto);
+		}
+
+	      if (!number_only)
+		{
+		  if (board_info->last_name == NULL
+		      || strcmp(board_info->last_name, response.name) != 0)
+		    {
+		      if (board_info->last_name != NULL)
+			G_FREE(board_info->last_name);
+		      board_info->last_name = G_STRDUP(response.name);
+		    }
+
+		  if (board_info->last_mail == NULL
+		      || strcmp(board_info->last_mail, response.mailto) != 0)
+		    {
+		      if (board_info->last_mail != NULL)
+			G_FREE(board_info->last_mail);
+		      board_info->last_mail = G_STRDUP(response.mailto);
+		    }
+
+		  if (application->last_name == NULL
+		      || strcmp(application->last_name, response.name) != 0)
+		    {
+		      if (application->last_name != NULL)
+			G_FREE(application->last_name);
+		      application->last_name = G_STRDUP(response.name);
+		    }
+
+		  if (application->last_mail == NULL
+		      || strcmp(application->last_mail, response.mailto) != 0)
+		    {
+		      if (application->last_mail != NULL)
+			G_FREE(application->last_mail);
+		      application->last_mail = G_STRDUP(response.mailto);
+		    }
+		}
+	    }
+	}
+      else
+	{
+	  /* ʸʤϥ顼ˤʤ餷 */
+	  result = TRUE;
+	  response_id = GTK_RESPONSE_CANCEL;
+	}
+    }
+  else
+    result = TRUE;
+
+  gtk_widget_destroy(write_dialog);
+
+  if (result)
+    {
+      if (response_id == GTK_RESPONSE_OK)
+	refresh_current_thread(application);
+    }
+  else
     ochusha_open_url(application,
 		     ochusha_bbs_thread_get_url_to_post_response(thread),
 		     FALSE, TRUE);
-  }
 }
 
 
@@ -1708,3 +1843,89 @@ go_to_top_button_cb(GtkWidget *widget, OchushaApplication *application)
 {
   go_to_the_first_response_of_current_thread(application);
 }
+
+
+static GtkWidget *
+create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
+{
+  GtkWidget *write_dialog;
+  GtkWidget *dialog_vbox;
+  GtkWidget *editor;
+  ResponseEditor *response_editor;
+  BBSThreadGUIInfo *thread_info = ensure_bbs_thread_info(thread);
+  BulletinBoardGUIInfo *board_info = ensure_bulletin_board_info(thread->board,
+								application);
+  gboolean has_name = FALSE;
+  gboolean has_mail = FALSE;
+
+  write_dialog = gtk_dialog_new_with_buttons(_("Write a response"),
+			application->top_level,
+			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_OK, GTK_RESPONSE_OK,
+			NULL);
+  gtk_window_set_position(GTK_WINDOW(write_dialog), GTK_WIN_POS_CENTER);
+  gtk_window_set_default_size(GTK_WINDOW(write_dialog), -1, 250);
+
+  dialog_vbox = GTK_DIALOG(write_dialog)->vbox;
+  editor = response_editor_new(thread);
+  response_editor = RESPONSE_EDITOR(editor);
+
+  if (thread_info->last_name != NULL)
+    {
+      response_editor_add_name(response_editor, thread_info->last_name);
+      response_editor_set_name(response_editor, thread_info->last_name);
+      has_name = TRUE;
+    }
+
+  if (thread_info->last_mail != NULL)
+    {
+      response_editor_add_mail(response_editor, thread_info->last_mail);
+      response_editor_set_mail(response_editor, thread_info->last_mail);
+      has_mail = TRUE;
+    }
+
+  if (board_info->last_name != NULL)
+    {
+      response_editor_add_name(response_editor, board_info->last_name);
+      if (!has_name)
+	{
+	  response_editor_set_name(response_editor, board_info->last_name);
+	  has_name = TRUE;
+	}
+    }
+
+  if (board_info->last_mail != NULL)
+    {
+      response_editor_add_mail(response_editor, board_info->last_mail);
+      if (!has_mail)
+	{
+	  response_editor_set_mail(response_editor, board_info->last_mail);
+	  has_mail = TRUE;
+	}
+    }
+
+  if (application->last_name != NULL)
+    {
+      response_editor_add_name(response_editor, application->last_name);
+      if (!has_name)
+	response_editor_set_name(response_editor, application->last_name);
+    }
+
+  if (application->last_mail != NULL)
+    {
+      response_editor_add_mail(response_editor, application->last_mail);
+      if (!has_mail)
+	response_editor_set_mail(response_editor, application->last_mail);
+    }
+
+  gtk_widget_show(editor);
+
+  gtk_box_pack_start(GTK_BOX(dialog_vbox), editor, TRUE, TRUE, 0);
+
+  g_object_set_data(G_OBJECT(write_dialog), "editor", editor);
+
+  gtk_widget_show_all(write_dialog);
+
+  return write_dialog;
+}
