@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.19 2003/06/22 14:39:36 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.20 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -747,7 +747,8 @@ main_menu_callback(gpointer data, guint action, GtkWidget *widget)
 	  "    </attribute>\n", (config)->attribute ? "true" : "false" )
 
 #define OUTPUT_CONFIG_ATTRIBUTE_STRING(file, config, attribute)	\
-  fprintf(file,							\
+  if ((config)->attribute != NULL)				\
+    fprintf(file,						\
 	  "    <attribute name=\"" #attribute	"\">\n"		\
 	  "      <string>%s</string>\n"				\
 	  "    </attribute>\n", (config)->attribute)
@@ -807,6 +808,9 @@ write_optional_prefs(FILE *file, gpointer user_data)
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
 				  hide_hidden_boardlist_items);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, hide_hidden_threads);
+
+  OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, last_name);
+  OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, last_mail);
 }
 
 
@@ -1091,6 +1095,11 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
 					  "hide_hidden_boardlist_items");
   application->hide_hidden_threads
     = ochusha_utils_get_attribute_boolean(pref_attrs, "hide_hidden_threads");
+
+  application->last_name = ochusha_utils_get_attribute_string(pref_attrs,
+							      "last_name");
+  application->last_mail = ochusha_utils_get_attribute_string(pref_attrs,
+							      "last_mail");
 }
 
 
